@@ -864,7 +864,7 @@ class Pulse(object):
 			"source" can be either int index of pulseaudio source
 				(i.e. source.index), its name (source.name), or None to use default source.
 			Resulting value is what pulseaudio returns as
-				PA_SAMPLE_FLOAT32BE float after "timeout" seconds.
+				PA_SAMPLE_FLOAT32NE float after "timeout" seconds.
 			If specified source does not exist, 0 should be returned after timeout.
 			This can be used to detect if there's any sound
 				on the microphone or any sound played through a sink via its monitor_source index,
@@ -874,7 +874,7 @@ class Pulse(object):
 			Example - get peak for specific sink input "si" for 0.8 seconds:
 				pulse.get_peak_sample(pulse.sink_info(si.sink).monitor_source, 0.8, si.index)'''
 		samples, proplist = [0], c.pa.proplist_from_string('application.id=org.PulseAudio.pavucontrol')
-		ss = c.PA_SAMPLE_SPEC(format=c.PA_SAMPLE_FLOAT32BE, rate=25, channels=1)
+		ss = c.PA_SAMPLE_SPEC(format=c.PA_SAMPLE_FLOAT32NE, rate=25, channels=1)
 		s = c.pa.stream_new_with_proplist(self._ctx, 'peak detect', c.byref(ss), None, proplist)
 		c.pa.proplist_free(proplist)
 
